==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/rmat/bean/SettleRepairEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-维修金额
 *
 * @author generator
 */
@TableName("ejc_prormat_settle_repair")
public class SettleRepairEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "restitute_bill_code")
    private String restituteBillCode; // 退赔单据编码
    @TableField(value = "repair_tax_mny")
    private BigDecimal repairTaxMny; // 本次维修金额
    @TableField(value = "repair_mny")
    private BigDecimal repairMny; // 本次维修金额(无税)
    @TableField(value = "repair_tax")
    private BigDecimal repairTax; // 维修税额
    @TableField(value = "refund_date")
    private Date refundDate; // 退赔日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getRestituteBillCode() {
        return restituteBillCode;
    }

    public void setRestituteBillCode(String restituteBillCode) {
        this.restituteBillCode = restituteBillCode;
    }

    public BigDecimal getRepairTaxMny() {
        return repairTaxMny;
    }

    public void setRepairTaxMny(BigDecimal repairTaxMny) {
        this.repairTaxMny = repairTaxMny;
    }

    public BigDecimal getRepairMny() {
        return repairMny;
    }

    public void setRepairMny(BigDecimal repairMny) {
        this.repairMny = repairMny;
    }

    public BigDecimal getRepairTax() {
        return repairTax;
    }

    public void setRepairTax(BigDecimal repairTax) {
        this.repairTax = repairTax;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-assistrmat-impl-3.0.0-20230426.023007-360-sources.jar: com/ejianc/business/assist/rmat/bean/SettleRepairEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-维修金额
 *
 * @author generator
 */
@TableName("ejc_assistrmat_settle_repair")
public class SettleRepairEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "restitute_bill_code")
    private String restituteBillCode; // 退赔单据编码
    @TableField(value = "repair_tax_mny")
    private BigDecimal repairTaxMny; // 本次维修金额
    @TableField(value = "repair_mny")
    private BigDecimal repairMny; // 本次维修金额(无税)
    @TableField(value = "repair_tax")
    private BigDecimal repairTax; // 维修税额
    @TableField(value = "refund_date")
    private Date refundDate; // 退赔日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getRestituteBillCode() {
        return restituteBillCode;
    }

    public void setRestituteBillCode(String restituteBillCode) {
        this.restituteBillCode = restituteBillCode;
    }

    public BigDecimal getRepairTaxMny() {
        return repairTaxMny;
    }

    public void setRepairTaxMny(BigDecimal repairTaxMny) {
        this.repairTaxMny = repairTaxMny;
    }

    public BigDecimal getRepairMny() {
        return repairMny;
    }

    public void setRepairMny(BigDecimal repairMny) {
        this.repairMny = repairMny;
    }

    public BigDecimal getRepairTax() {
        return repairTax;
    }

    public void setRepairTax(BigDecimal repairTax) {
        this.repairTax = repairTax;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
